summaryrefslogtreecommitdiff
path: root/nuttx/drivers/mtd/ftl.c
diff options
context:
space:
mode:
authorpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2009-12-16 23:23:46 +0000
committerpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2009-12-16 23:23:46 +0000
commitcef4fec60cb7f31f81f887fcfd729be41662abb1 (patch)
tree0d46ddbbeaa56d21bde1660d97c4e34c31539f11 /nuttx/drivers/mtd/ftl.c
parent471b50c5f8f0f49ce8abfb8f0085d05cfe32edaa (diff)
downloadnuttx-cef4fec60cb7f31f81f887fcfd729be41662abb1.tar.gz
nuttx-cef4fec60cb7f31f81f887fcfd729be41662abb1.tar.bz2
nuttx-cef4fec60cb7f31f81f887fcfd729be41662abb1.zip
Clean-up from big switch to stdint/stdbool
git-svn-id: svn://svn.code.sf.net/p/nuttx/code/trunk@2362 42af7a65-404d-4744-a932-0658087f49c3
Diffstat (limited to 'nuttx/drivers/mtd/ftl.c')
-rwxr-xr-xnuttx/drivers/mtd/ftl.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/nuttx/drivers/mtd/ftl.c b/nuttx/drivers/mtd/ftl.c
index 1e9ab5ebd..11ed83f63 100755
--- a/nuttx/drivers/mtd/ftl.c
+++ b/nuttx/drivers/mtd/ftl.c
@@ -475,12 +475,12 @@ int ftl_initialize(int minor, uint8_t *buffer, FAR struct mtd_dev_s *mtd)
dev->mtd = mtd;
/* Get the device geometry. (casting to uintptr first eliminates
* complaints on some architectures where the sizeof long is different
* from the size of a pointer).
*/
- ret = MTD_IOCTL(mtd, MTDIOC_GEOMETRY, (unsigned long)((uintptr)&dev->geo));
+ ret = MTD_IOCTL(mtd, MTDIOC_GEOMETRY, (unsigned long)((uintptr_t)&dev->geo));
if (ret < 0)
{
fdbg("MTD ioctl(MTDIOC_GEOMETRY) failed: %d\n", ret);
@@ -503,7 +503,7 @@ int ftl_initialize(int minor, uint8_t *buffer, FAR struct mtd_dev_s *mtd)
/* Get the number of R/W blocks per erase block */
dev->blkper = dev->geo.erasesize / dev->geo.blocksize;
- DEBUGASSERT(dev->blkper * dev->geo.blocksize = dev->geo.erasesize);
+ DEBUGASSERT(dev->blkper * dev->geo.blocksize == dev->geo.erasesize);
/* Configure read-ahead/write buffering */
@@ -475,12 +475,12 @@ int ftl_initialize(int minor, uint8_t *buffer, FAR struct mtd_dev_s *mtd)
dev->mtd = mtd;
- /* Get the device geometry. (casting to uintptr first eliminates
+ /* Get the device geometry. (casting to uintptr_t first eliminates
* complaints on some architectures where the sizeof long is different
* from the size of a pointer).